@@ -1,5 +1,6 @@
+#' @export
 koyckDlm.default <-
-  function(x , y ,  show.summary = TRUE){
+  function(x , y ){
     
     options(warn=-1)
     
@@ -7,7 +8,7 @@ koyckDlm.default <-
       stop("Data series x and y both must be in a vector format!")
     }
   
-    res = koyckDlm.main(x , y ,  show.summary)
+    res = koyckDlm.main(x , y)
     res$call = match.call()
     class(res) = c("koyckDlm" , "dLagM")
     res
