@@ -1,4 +1,7 @@
-polyDlmForecast.main = function(model , x , h = 1 ){
+polyDlmForecast.main = function(model , x , h = 1 , epsilon = NULL){
+  if (is.null(epsilon) == TRUE){
+    epsilon = array(0, h)
+  }
   forecasts = array(NA, h)
   coefs = model$model$coefficients
   n = nrow(model$designMatrix.x)
@@ -12,7 +15,7 @@ polyDlmForecast.main = function(model , x , h = 1 ){
   tr.matrix = model$transformation.matrix
   for (i in 1:h){
     z = c(1 , tr.matrix %*% x.obs)
-    forecasts[i] = as.vector(coefs)%*%z
+    forecasts[i] = as.vector(coefs)%*%z + epsilon[i]
     x.obs = guyrot(x.obs,1)
     if (i != h){
       x.obs[1] = x[(i+1)]
